@@ -57,6 +57,7 @@ start_animation (void)
 
 	druid_data.throbber_id = gtk_timeout_add (150, animate, NULL);
 	gtk_widget_show (GET_WIDGET ("gdb-progress"));
+	gtk_widget_set_sensitive (GET_WIDGET ("gdb-copy-save-box"), FALSE);
 }
 
 static void
@@ -67,6 +68,7 @@ stop_animation (void)
 	gtk_timeout_remove (druid_data.throbber_id);
 	druid_data.throbber_id = 0;
 	gtk_widget_hide (GET_WIDGET ("gdb-progress"));
+	gtk_widget_set_sensitive (GET_WIDGET ("gdb-copy-save-box"), TRUE);
 }
 
 void
@@ -254,6 +256,7 @@ void
 get_trace_from_pair (const gchar *app, const gchar *extra)
 {
 	GtkWidget *d;
+	char *s;
 	char *app2;
 	char *args[] = { "gdb",
 			 "--batch", 
@@ -332,10 +335,13 @@ get_trace_from_pair (const gchar *app, const gchar *extra)
 	}
 	
 	druid_data.ioc = g_io_channel_unix_new (druid_data.fd);
+	
+	s = g_strdup_printf ("Backtrace was generated from '%s'\n\n", app2);
+	buddy_set_text ("gdb-text", s);
+	g_free (s);
 	g_io_add_watch (druid_data.ioc, G_IO_IN | G_IO_HUP,
 			handle_gdb_input, NULL);
 	g_io_channel_unref (druid_data.ioc);
-	buddy_set_text ("gdb-text", NULL);
 
 	druid_set_sensitive (FALSE, FALSE, TRUE);
 	start_animation ();
